@@ -114,6 +114,7 @@
 #define LABEL_ROUNDS_PER_SEC_LIMIT "ROUNDS_PER_SEC_LIMIT"
 #define LABEL_SERVER_ADDRESS "SERVER_ADDRESS"
 #define LABEL_SERVER_PORT "SERVER_PORT"
+#define LABEL_ASM_ALGORITHM "ASM_ALGORITHM"
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
@@ -156,6 +157,9 @@ int CONFIG_FRAMES_PER_SEC_LIMIT;
 int CONFIG_ROUNDS_PER_SEC_LIMIT;
 char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
 int CONFIG_SERVER_PORT;
+int CONFIG_ASM_ALGORITHM;
+
+LW_NETCONF LW_CONFIG_CURRENT_RULES;
 
 /*==================================================================*/
 /* constantes globales                                              */
@@ -181,7 +185,7 @@ void load_default_options (void)
   CONFIG_GFX_MENU=2;
 #endif
   CONFIG_FULLSCREEN=1;
-  CONFIG_VIEWPORT_SIZE=5;
+  CONFIG_VIEWPORT_SIZE=6;
  
   CONFIG_WAVE_NUMBER[0]=2;
   CONFIG_WAVE_NUMBER[1]=2;
@@ -263,7 +267,7 @@ void load_default_options (void)
   strcpy(CONFIG_PLAYER_NAME[5],"Attila");
 
   CONFIG_GAME_TIME=8;
-  CONFIG_INFO_BAR=2;
+  CONFIG_INFO_BAR=1;
   CONFIG_MOUSE_GAP=4;
   CONFIG_JOYSTICK_ON=1;
   CONFIG_CPU_ADVANTAGE=0;
@@ -276,6 +280,8 @@ void load_default_options (void)
 
   strcpy(CONFIG_SERVER_ADDRESS,LW_SERVER_DEFAULT_ADDRESS);
   CONFIG_SERVER_PORT=LW_SERVER_DEFAULT_PORT;
+
+  CONFIG_ASM_ALGORITHM=1;
 }
 
 /*------------------------------------------------------------------*/
@@ -349,6 +355,7 @@ static int load_disk_options (void)
 
       CONFIG_SERVER_PORT=get_config_int(LABEL_MAIN,LABEL_SERVER_PORT,CONFIG_SERVER_PORT);
 
+      CONFIG_ASM_ALGORITHM=get_config_int(LABEL_MAIN,LABEL_ASM_ALGORITHM,CONFIG_ASM_ALGORITHM);
       return 1;
     }
   else
@@ -361,11 +368,14 @@ static int load_disk_options (void)
 int load_config_options (void)
 {
   int result;
+
   result=load_disk_options();
 
-#ifdef ALLEGRO_WINDOWS
-  CONFIG_PAGE_FLIP=0;
-#endif
+  /*
+   * Any special hack can go here 8-)
+   */
+  lw_config_set_current_rules_to_default();
+
   return result;
 }
 
@@ -437,6 +447,8 @@ int save_config_options (void)
   set_config_string(LABEL_MAIN,LABEL_SERVER_ADDRESS,CONFIG_SERVER_ADDRESS);
   set_config_int(LABEL_MAIN,LABEL_SERVER_PORT,CONFIG_SERVER_PORT);
 	
+  set_config_int(LABEL_MAIN,LABEL_ASM_ALGORITHM,CONFIG_ASM_ALGORITHM);
+
   return 0;
 }
 
@@ -451,4 +463,20 @@ void check_config_range (void)
     CONFIG_LEVEL_BG=CHOOSE_COLOR_BLACK;
 }
 
+/*------------------------------------------------------------------*/
+void lw_config_set_current_rules_to_default (void)
+{
+  LW_NETCONF *config;
 
+  config=&LW_CONFIG_CURRENT_RULES;
+
+  config->cursor_increase_speed=CONFIG_CURSOR_INCREASE_SPEED;
+  config->fighter_attack=CONFIG_FIGHTER_ATTACK;
+  config->fighter_defense=CONFIG_FIGHTER_DEFENSE;
+  config->fighter_new_health=CONFIG_FIGHTER_NEW_HEALTH;
+  config->number_influence=CONFIG_NUMBER_INFLUENCE;
+  config->fighter_number=CONFIG_FIGHTER_NUMBER;
+  config->game_time=CONFIG_GAME_TIME;
+  config->cpu_advantage=CONFIG_CPU_ADVANTAGE;
+  config->asm_algorithm=CONFIG_ASM_ALGORITHM && STARTUP_ASM;
+}
