@@ -74,12 +74,14 @@
 #include "mouse.h"
 #include "log.h"
 #include "thrdgen.h"
+#include "chat.h"
+#include "netmess.h"
 
 /*==================================================================*/
 /* globals                                                          */
 /*==================================================================*/
 
-#define CONNECT_BUF_SIZE 100
+#define CONNECT_BUF_SIZE 200
 
 typedef struct
 {
@@ -91,6 +93,9 @@ typedef struct
   int thread_running;
   int result;
   int finished;
+  char chat_buffer[LW_CHAT_MESSAGE_SIZE+1];
+  LW_CHAT_HISTORY chat_history;
+  int chat_send;
 } LW_CONNECT_DATA;
 
 LW_CONNECT_DATA GLOBAL_CONNECT_DATA;
@@ -102,17 +107,21 @@ LW_CONNECT_DATA GLOBAL_CONNECT_DATA;
 static void connect_on_server_keepalive(void *args);
 static int update_connect_menu(DIALOG *d,
 			       int waited_teams,
-			       LW_TEAMSTARTINFO *team_start_info);
+			       LW_TEAMSTARTINFO *team_start_info,
+			       LW_CHAT_HISTORY *chat_history);
 static void position_players_list (DIALOG *d);
+static void position_chat_history (DIALOG *d);
 
 /*------------------------------------------------------------------*/
 int lw_connect_menu (int sock)
 {
-  DIALOG d[8];
+  DIALOG d[12];
   DIALOG_PLAYER *dp;
   int choix=4,retour=0;
   char buf_waited_teams[CONNECT_BUF_SIZE];
   char buf_connected_players[NB_TEAMS*CONNECT_BUF_SIZE];
+  char buf_chat_history[LW_CHAT_HISTORY_SIZE*CONNECT_BUF_SIZE];
+  char buf_chat_message[LW_CHAT_MESSAGE_SIZE+1];
   int first_display=1;
   int first_getinfo=1;
   LW_CONNECT_DATA *data;
@@ -122,6 +131,8 @@ int lw_connect_menu (int sock)
   memset(d,0,sizeof(d));
   buf_waited_teams[0]='\0';
   buf_connected_players[0]='\0';
+  buf_chat_history[0]='\0';
+  buf_chat_message[0]='\0';
 
   data=&GLOBAL_CONNECT_DATA;
   memset(data,0,sizeof(LW_CONNECT_DATA));
@@ -132,18 +143,38 @@ int lw_connect_menu (int sock)
 
   while (retour==0)
     {
-      standard_big_button (d+4,0,0,1,6);
-      standard_button (d+6,0,5,1,6);
+      standard_button (d+4,1,0,2,10);
+      standard_button (d+6,1,5,2,10);
+      standard_button (d+8,1,7,2,10);
+      standard_button (d+9,1,7,2,10);
+      standard_button (d+10,1,8,2,10);
 
       quick_buttons(d);
 
       d[4].proc=my_textbox_proc;
       d[5].proc=my_textbox_proc;
+      d[7].proc=my_textbox_proc;
+      d[8].proc=my_textbox_proc;
+      d[9].proc=my_edit_proc;
+
       position_players_list(d+5);
+      position_chat_history(d+7);
+      d[4].w=d[7].w;
+      d[8].w=d[7].w;
+      d[9].w=d[7].w;
+      d[9].x++;
+      d[9].y++;
+      d[9].w-=2;
+      d[9].h-=2;
 
       d[4].dp=buf_waited_teams;
       d[5].dp=buf_connected_players;
       d[6].dp=lw_lang_string(LW_LANG_STRING_CONNECT_STARTNOW);
+      d[7].dp=buf_chat_history;
+      d[8].dp="";
+      d[9].dp=buf_chat_message;
+      d[9].d1=LW_CHAT_MESSAGE_SIZE;
+      d[10].dp=lw_lang_string(LW_LANG_STRING_CONNECT_SENDMESSAGE);
 
       if (hide_start_button)
 	{
@@ -151,7 +182,7 @@ int lw_connect_menu (int sock)
 	  d[6].dp=lw_lang_string(LW_LANG_STRING_CONNECT_WAITING);
 	}
 
-      d[7].proc=0;
+      d[11].proc=0;
 
       if (first_display)
 	{
@@ -174,7 +205,8 @@ int lw_connect_menu (int sock)
 		    {
 		      update_connect_menu(d,
 					  data->waited_teams,
-					  data->team_start_info);
+					  data->team_start_info,
+					  &(data->chat_history));
 		    }
 		}
 	      data->thread_running=1;
@@ -241,6 +273,18 @@ int lw_connect_menu (int sock)
 		      display_back_image();
 		    }		 
 		  break;
+		case 10:
+		  if (strlen(d[9].dp) && !data->chat_send)
+		    {
+		      data->chat_send=1;
+
+		      strncpy(data->chat_buffer,d[9].dp,LW_CHAT_MESSAGE_SIZE);
+		      data->chat_buffer[LW_CHAT_MESSAGE_SIZE]='\0';
+		      ((char *) (d[9].dp))[0]='\0';
+		      d[9].d2=0;
+		      d[9].proc(MSG_DRAW,d+9,0);
+		    }
+		  break;
 		}
 	    }
 	}
@@ -267,12 +311,17 @@ int lw_connect_menu (int sock)
  */
 static int update_connect_menu(DIALOG *d,
 			       int waited_teams,
-			       LW_TEAMSTARTINFO *team_start_info)
+			       LW_TEAMSTARTINFO *team_start_info,
+			       LW_CHAT_HISTORY *chat_history)
 {
   int result=0;
   int i;
   char *sep;
   char buf[CONNECT_BUF_SIZE];
+  LW_CHAT_MESSAGE chat_mess;
+  static int old_chat_length=0;
+  int chat_length;
+  int l;
 
   sprintf(d[4].dp,"%s%d%s",
 	  lw_lang_string(LW_LANG_STRING_CONNECT_WAITINGFOR),
@@ -300,9 +349,33 @@ static int update_connect_menu(DIALOG *d,
 	}
     }
 
+  ((char *) (d[7].dp))[0]='\0';
+  for (i=0;lw_chat_get(chat_history,&chat_mess,i);++i)
+    {
+      sprintf(buf,"%s: %s\n",
+	      chat_mess.author,chat_mess.content);
+      strcat(d[7].dp,buf);
+    }
+  /*
+   * Now if the length of the string has changed, we
+   * scroll to the end of the list. The "string length"
+   * test is not 100% safe, but its purpose is just to
+   * scroll through the list when a message is sent.
+   * if it fails sometimes, it's not _that_ bad.
+   */
+  chat_length=strlen(d[7].dp);
+  if (chat_length!=old_chat_length)
+    {
+      old_chat_length=chat_length;
+      
+      l = (d[7].h-8)/text_height(font);
+      d[7].d2 = MAX(0, d[7].d1-l);
+    }
+
   scare_mouse();
   d[4].proc(MSG_DRAW,d+4,0);
   d[5].proc(MSG_DRAW,d+5,0);
+  d[7].proc(MSG_DRAW,d+7,0);
   unscare_mouse();
 
   show_mouse(screen);
@@ -343,6 +416,26 @@ static void connect_on_server_keepalive(void *arg)
 	}
     }
 
+  if (result==1 && data->chat_send)
+    {
+      lw_netmess_cleanup_arg(data->chat_buffer);
+
+      if (!lw_protocol_chat_talk(data->sock,data->chat_buffer))
+	{
+	  result=0;
+	}
+
+      data->chat_send=0;
+    }
+
+  if (result==1)
+    {
+      if (!lw_protocol_chat_listen(data->sock,&(data->chat_history)))
+	{
+	  result=0;
+	}
+    }
+
   if (result==1 && data->force_start)
     {
       if (!lw_protocol_force_start(data->sock))
@@ -381,12 +474,26 @@ static void connect_on_server_keepalive(void *arg)
 
 /*------------------------------------------------------------------*/
 void position_players_list (DIALOG *d) {
-  d->x=MENU_VIRTUAL_W/2-(3*MENU_W_STANDARD)/4;
-  d->y=MENU_VIRTUAL_H/2-(4*MENU_H_STANDARD+3*MENU_H_SPACE)/2;
-  d->w=(3*MENU_W_STANDARD)/2;
+  d->x=(MENU_VIRTUAL_W+MENU_W_SPACE)/2;
+  d->y=(MENU_VIRTUAL_H-MENU_H_INTERNET_LIST)/2+MENU_H_STANDARD+MENU_H_SPACE;
+  d->w=(MENU_W_STANDARD+MENU_W_INTERNET_LIST)/2;
   d->h=4*MENU_H_STANDARD+3*MENU_H_SPACE;
 
   color_one_dialog (d);
   menu_real_coord (d);
 }
 
+/*------------------------------------------------------------------*/
+void position_chat_history (DIALOG *d) {
+  d->x=(MENU_VIRTUAL_W-MENU_W_SPACE)/2-MENU_W_INTERNET_LIST;
+  d->y=(MENU_VIRTUAL_H-MENU_H_INTERNET_LIST)/2;
+  d->w=MENU_W_INTERNET_LIST;
+  d->h=MENU_H_INTERNET_LIST;
+
+  color_one_dialog (d);
+  menu_real_coord (d);
+  d->key=0;
+  d->dp="";
+  d->flags=D_EXIT;
+}
+
