@@ -58,6 +58,7 @@
 #include "sound.h"
 #include "back.h"
 #include "lang.h"
+#include "exit.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -241,8 +242,19 @@ void main_info (DIALOG *d, char *str)
 int my_do_dialog_no_clear (DIALOG *d, int f)
 {
   int result;
-
-  result=do_dialog (d,f);
+  void *player;
+  
+  player = init_dialog(d, f);
+  
+  while (my_update_dialog(player))
+    {
+      /*
+       * Nothing here...
+       */
+    }
+  
+  result = shutdown_dialog(player);
+  
   play_click();
 
   return result;
@@ -259,6 +271,17 @@ int my_do_dialog (DIALOG *d, int f)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+int my_update_dialog (DIALOG_PLAYER *player)
+{
+  int result;
+
+  result=update_dialog(player);
+  my_exit_poll();
+
+  return result;
+}
+
 /*------------------------------------------------------------------*/
 void display_center_message (char *str)
 {
@@ -271,7 +294,7 @@ void display_center_message (char *str)
   main_message (d,str);
   d[1].proc=0;
   dp=init_dialog (d,0);
-  update_dialog (dp);
+  my_update_dialog (dp);
   shutdown_dialog (dp);
 
   /*
