@@ -61,6 +61,7 @@
 #include "spread.h"
 #include "startup.h"
 #include "time.h"
+#include "config.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -75,53 +76,53 @@
 /*------------------------------------------------------------------*/
 BITMAP *create_gradient_bitmap (int team)
 {
- BITMAP *result;
- int x,y,i,color;
- MESH *temp;
+  BITMAP *result;
+  int x,y,i,color;
+  MESH *temp;
 
- result=my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
+  result=my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
 
- if (result)
+  if (result)
     {
-     i=0;
-     for (y=0; y<CURRENT_AREA_H; ++y)
-     for (x=0; x<CURRENT_AREA_W; ++x)
-         {
-          if ((temp=CURRENT_AREA[i++].mesh)!=NULL)
-            {
-             color=(temp->info[team].state.grad
-             +AREA_START_GRADIENT)%COLORS_PER_TEAM;
-             putpixel (result, x, y,
-             color+COLOR_FIRST_ENTRY[team]);
-            }
-          else
+      i=0;
+      for (y=0; y<CURRENT_AREA_H; ++y)
+	for (x=0; x<CURRENT_AREA_W; ++x)
+	  {
+	    if ((temp=CURRENT_AREA[i++].mesh)!=NULL)
+	      {
+		color=(temp->info[team].state.grad
+		       +AREA_START_GRADIENT)%COLORS_PER_TEAM;
+		putpixel (result, x, y,
+			  color+COLOR_FIRST_ENTRY[team]);
+	      }
+	    else
               putpixel (result, x, y, MENU_BG);
-         }
+	  }
     }
 
- return result;
+  return result;
 }
 
 /*------------------------------------------------------------------*/
 BITMAP *create_dir_bitmap (int team)
 {
- BITMAP *result;
- int x,y,i;
- MESH *temp;
+  BITMAP *result;
+  int x,y,i;
+  MESH *temp;
 
- result=my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
+  result=my_create_bitmap (CURRENT_AREA_W, CURRENT_AREA_H);
 
- i=0;
- for (y=0; y<CURRENT_AREA_H; ++y)
-     for (x=0; x<CURRENT_AREA_W; ++x)
-         {
-          if ((temp=CURRENT_AREA[i++].mesh)!=NULL)
-             putpixel (result, x, y, 134
-             +(temp->info[team].state.dir/4)*42
-             +(temp->info[team].state.dir%4)*10);
-         }
+  i=0;
+  for (y=0; y<CURRENT_AREA_H; ++y)
+    for (x=0; x<CURRENT_AREA_W; ++x)
+      {
+	if ((temp=CURRENT_AREA[i++].mesh)!=NULL)
+	  putpixel (result, x, y, 134
+		    +(temp->info[team].state.dir/4)*42
+		    +(temp->info[team].state.dir%4)*10);
+      }
 
- return result;
+  return result;
 }
 
 /*------------------------------------------------------------------*/
@@ -131,114 +132,114 @@ BITMAP *create_dir_bitmap (int team)
 /*------------------------------------------------------------------*/
 void spread_single_gradient (void)
 {
- int i,new_grad,dir;
- MESH *pos,*last;
- MESH *temp;
+  int i,new_grad,dir;
+  MESH *pos,*last;
+  MESH *temp;
 
- dir=(GLOBAL_CLOCK*7)%NB_DIRS;
- switch (dir)
- {
-  case DIR_ENE :
-  case DIR_ESE :
-  case DIR_SE  :
-  case DIR_SSE :
-  case DIR_SSW :
-  case DIR_SW  :
-     pos=CURRENT_MESH+1;
-     last=CURRENT_MESH+CURRENT_MESH_SIZE;
-  #ifndef ALLEGRO_UNIX
-  if (STARTUP_ASM)
-     switch (PLAYING_TEAMS)
-            {
-             case 6 :
-                  boost_gradient_down_6
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             case 5 :
-                  boost_gradient_down_5
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             case 4 :
-                  boost_gradient_down_4
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             case 3 :
-                  boost_gradient_down_3
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             default :
-                  boost_gradient_down_2
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-            }
-  else
-  #endif
-     while (pos!=last)
-         {
-         for (i=0;i<PLAYING_TEAMS;++i)
-          if (   (temp=(pos->link[dir]))
-              && (temp->info[i].state.grad
-              >  (new_grad=pos->info[i].state.grad+pos->side.size)))
-              temp->info[i].state.grad=new_grad;
-          pos++;
+  dir=(GLOBAL_CLOCK*7)%NB_DIRS;
+  switch (dir)
+    {
+    case DIR_ENE :
+    case DIR_ESE :
+    case DIR_SE  :
+    case DIR_SSE :
+    case DIR_SSW :
+    case DIR_SW  :
+      pos=CURRENT_MESH+1;
+      last=CURRENT_MESH+CURRENT_MESH_SIZE;
+#ifdef ASM
+      if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
+	switch (PLAYING_TEAMS)
+	  {
+	  case 6 :
+	    boost_gradient_down_6
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  case 5 :
+	    boost_gradient_down_5
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  case 4 :
+	    boost_gradient_down_4
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  case 3 :
+	    boost_gradient_down_3
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  default :
+	    boost_gradient_down_2
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  }
+      else
+#endif
+	while (pos!=last)
+	  {
+	    for (i=0;i<PLAYING_TEAMS;++i)
+	      if (   (temp=(pos->link[dir]))
+		     && (temp->info[i].state.grad
+			 >  (new_grad=pos->info[i].state.grad+pos->side.size)))
+		temp->info[i].state.grad=new_grad;
+	    pos++;
           }
-     break;
-  case DIR_WSW :
-  case DIR_WNW :
-  case DIR_NW  :
-  case DIR_NNW :
-  case DIR_NNE :
-  case DIR_NE  :
-     pos=CURRENT_MESH+CURRENT_MESH_SIZE-1;
-     last=CURRENT_MESH;
-  #ifndef ALLEGRO_UNIX
-  if (STARTUP_ASM)
-     switch (PLAYING_TEAMS)
-            {
-             case 6 :
-                  boost_gradient_up_6
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             case 5 :
-                  boost_gradient_up_5
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             case 4 :
-                  boost_gradient_up_4
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             case 3 :
-                  boost_gradient_up_3
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-             default :
-                  boost_gradient_up_2
-                  (pos, CURRENT_MESH_SIZE-1,
-                  OFFSET_TO_FIRST_LINK+dir*4);
-                  break;
-            }
-  else
-   #endif
-     while (pos!=last)
-         {
-         for (i=0;i<PLAYING_TEAMS;++i)
-          if (   (temp=(pos->link[dir]))
-              && (temp->info[i].state.grad
-              >  (new_grad=pos->info[i].state.grad+pos->side.size)))
-              temp->info[i].state.grad=new_grad;
-          pos--;
-         }
-     break;
- }
+      break;
+    case DIR_WSW :
+    case DIR_WNW :
+    case DIR_NW  :
+    case DIR_NNW :
+    case DIR_NNE :
+    case DIR_NE  :
+      pos=CURRENT_MESH+CURRENT_MESH_SIZE-1;
+      last=CURRENT_MESH;
+#ifdef ASM
+      if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
+	switch (PLAYING_TEAMS)
+	  {
+	  case 6 :
+	    boost_gradient_up_6
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  case 5 :
+	    boost_gradient_up_5
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  case 4 :
+	    boost_gradient_up_4
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  case 3 :
+	    boost_gradient_up_3
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  default :
+	    boost_gradient_up_2
+	      (pos, CURRENT_MESH_SIZE-1,
+	       OFFSET_TO_FIRST_LINK+dir*4);
+	    break;
+	  }
+      else
+#endif
+	while (pos!=last)
+	  {
+	    for (i=0;i<PLAYING_TEAMS;++i)
+	      if (   (temp=(pos->link[dir]))
+		     && (temp->info[i].state.grad
+			 >  (new_grad=pos->info[i].state.grad+pos->side.size)))
+		temp->info[i].state.grad=new_grad;
+	    pos--;
+	  }
+      break;
+    }
 }
 
 
