@@ -59,6 +59,7 @@
 #include "config.h"
 #include "gfxmode.h"
 #include "init.h"
+#include "exit.h"
 #include "joystick.h"
 #include "log.h"
 #include "startup.h"
@@ -81,21 +82,18 @@ void display_success (int success)
     log_println_str (" - success!");
   else
     log_println_str (" - failed...");  
+
   log_flush();
   /* delay (100);*/
 }
 
 /*------------------------------------------------------------------*/
-void display_success_driver (int success, char *driver)
+void display_success_driver (char *driver)
 {
-  if (success)
-    {
-      log_print_str(" (driver=\"");
-      log_print_str(driver);
-      log_println_str ("\") - success!");
-    }
-  else
-    log_println_str (" - failed...");  
+  log_print_str(" (driver=\"");
+  log_print_str(driver);
+  log_println_str ("\") - success!");
+
   log_flush();
   /* delay (100);*/
 }
@@ -137,22 +135,49 @@ int init_all ()
   log_print_str(STARTUP_CFG_PATH);
   log_print_str("\"");
  
+  /*
+   * We call this now only (after loading the options), for
+   * options must be loaded for my_exit_close_button to work
+   */
+  set_window_close_button(TRUE);
+  set_window_close_hook(my_exit_close_button);
+
   display_success (config=load_config_options());
 
   log_print_str("Installing timer");
-
-  display_success_driver (timer=!install_timer (),
-			  (char *) timer_driver->ascii_name);
+  timer=!install_timer ();
+  if (timer)
+    {
+      display_success_driver((char *) timer_driver->ascii_name);
+    }
+  else
+    {
+      display_success(0);
+    }
 
   start_ticker();
 
-  log_print_str ("Installing keyboard");
-  display_success_driver (keyboard=!install_keyboard (),
-			  (char *) keyboard_driver->ascii_name);
+  log_print_str("Installing keyboard");
+  keyboard=!install_keyboard ();
+  if (keyboard)
+    {
+      display_success_driver((char *) keyboard_driver->ascii_name);
+    }
+  else
+    {
+      display_success(0);
+    }
 
-  log_print_str ("Installing mouse");
-  display_success_driver (mouse=install_mouse () != -1,
-			  (char *) mouse_driver->ascii_name);
+  log_print_str("Installing mouse");
+  mouse=install_mouse()!=-1;
+  if (mouse)
+    {
+      display_success_driver((char *) mouse_driver->ascii_name);
+    }
+  else
+    {
+      display_success(0);
+    }
 
   if (STARTUP_DIGI_CARD != DIGI_NONE || STARTUP_MIDI_CARD != MIDI_NONE)
     {
@@ -181,8 +206,15 @@ int init_all ()
     {
       log_print_str ("Installing joystick");
       if (STARTUP_JOYSTICK_ON)
-	display_success_driver (joystick=!my_initialise_joystick (),
-				(char *) joystick_driver->ascii_name);
+	joystick=!my_initialise_joystick ();
+      if (joystick)
+	{
+	  display_success_driver((char *) joystick_driver->ascii_name);
+	}
+      else
+	{
+	  display_success(0);
+	}
     }
 
   log_print_str("Setting up network");
@@ -202,7 +234,7 @@ int start_graphic (void)
 {
   int retour;
 
-  retour= (!set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN));
+  retour= (!set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN,NULL));
 
   return retour;
 }
