@@ -78,7 +78,7 @@
 
 /*------------------------------------------------------------------*/
 /*
- * Sends a map over the network
+ * Sends a config over the network
  */
 int lw_netconf_send(int sock, LW_NETCONF *config)
 {
@@ -117,7 +117,12 @@ int lw_netconf_send(int sock, LW_NETCONF *config)
 				      config->cpu_advantage);
 			      if (lw_sock_send_str(sock,buffer))
 				{
-				  result=1;
+				  sprintf(buffer,"%d",
+					  config->asm_algorithm);
+				  if (lw_sock_send_str(sock,buffer))
+				    {
+				      result=1;
+				    }
 				}
 			    }
 			}
@@ -132,7 +137,7 @@ int lw_netconf_send(int sock, LW_NETCONF *config)
 
 /*------------------------------------------------------------------*/
 /*
- * Receives a map from the network
+ * Receives a config from the network
  */
 int lw_netconf_recv(int sock, LW_NETCONF *config)
 {
@@ -165,8 +170,12 @@ int lw_netconf_recv(int sock, LW_NETCONF *config)
 			      if (lw_sock_recv_str(sock,buffer))
 				{
 				  config->cpu_advantage=atoi(buffer);
-
-				  result=1;
+				  if (lw_sock_recv_str(sock,buffer))
+				    {
+				      config->asm_algorithm=atoi(buffer);
+				      
+				      result=1;
+				    }
 				}
 			    }
 			}
