@@ -61,6 +61,7 @@
 
 #include "network.h"
 #include "startinf.h"
+#include "chat.h"
 
 /*==================================================================*/
 /* fonctions globales                                               */
@@ -85,5 +86,8 @@ int lw_protocol_force_start (int sock);
 int lw_protocol_next (int sock); 
 int lw_protocol_ask_teamstartinfo(int sock, int team,
 				  LW_TEAMSTARTINFO *team_start_info); 
+int lw_protocol_chat_talk(int sock, char *text);
+int lw_protocol_chat_listen(int sock, 
+			    LW_CHAT_HISTORY *chat_history); 
 
 #endif
