@@ -53,6 +53,7 @@
 /*==================================================================*/
 
 #include <string.h>
+#include <stdio.h>
 
 #include "advanced.h"
 #include "config.h"
@@ -63,6 +64,7 @@
 #include "rules.h"
 #include "sound.h"
 #include "time.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -75,27 +77,30 @@
 /*------------------------------------------------------------------*/
 static void write_time_setting (DIALOG *d)
 {
- char *str;
+  char *str;
 
- str=d->dp;
- start_play_time();
- write_time (TIME_LEFT,str+8);
+  str=d->dp;
+  start_play_time();
+  write_time (TIME_LEFT,str+8);
 }
 
 /*------------------------------------------------------------------*/
 static int slider_time (void *dp3, int d2)
 {
- DIALOG *d;
+  DIALOG *d;
 
- d=dp3;
+  d=dp3;
 
- CONFIG_GAME_TIME=d2;
- write_time_setting (d);
- my_textbox_proc (MSG_DRAW, d, 0);
+  CONFIG_GAME_TIME=d2;
+  write_time_setting (d);
 
- play_click ();
+  scare_mouse();
+  my_textbox_proc (MSG_DRAW, d, 0);
+  unscare_mouse();
 
- return 0;
+  play_click ();
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
@@ -107,36 +112,38 @@ int rules_options (void)
   static int y_pos[3]={0,1,3};
   char time_str[14];
   
-  strcpy(time_str,"Time    00:00");
+  memset(d,0,sizeof(d));
+
+  sprintf(time_str,"%-8s00:00",lw_lang_string(LW_LANG_STRING_RULES_TIME));
 
   for (i=0; i<2; ++i)
-      {
-       standard_button (d+i+4,0,y_pos[i],2,4);
-       d[i+4].proc=my_textbox_proc;
-      }
+    {
+      standard_button (d+i+4,0,y_pos[i],2,4);
+      d[i+4].proc=my_textbox_proc;
+    }
   for (i=0; i<2; ++i)
-      {
-       standard_button (d+i+6,1,y_pos[i],2,4);
-       d[i+6].proc=my_slider_proc;
-      }
+    {
+      standard_button (d+i+6,1,y_pos[i],2,4);
+      d[i+6].proc=my_slider_proc;
+    }
 
   standard_button (d+8,0,3,1,4);
-  d[8].dp="Advanced";
+  d[8].dp=lw_lang_string(LW_LANG_STRING_RULES_ADVANCED);
 
   quick_buttons(d);
-  d[4].dp="Army size";
+  d[4].dp=lw_lang_string(LW_LANG_STRING_RULES_ARMYSIZE);
   d[5].dp=time_str;
   d[6].d1=32;
   d[7].d1=16;
   d[6].dp3=&CONFIG_FIGHTER_NUMBER;
   d[7].dp3=&CONFIG_GAME_TIME;
   for (i=6;i<8;++i)
-      {
-       d[i].dp=NULL;
-       d[i].dp2=slider_int;
-       temp=d[i].dp3;
-       d[i].d2=*temp;
-      }
+    {
+      d[i].dp=NULL;
+      d[i].dp2=slider_int;
+      temp=d[i].dp3;
+      d[i].d2=*temp;
+    }
   d[7].dp2=slider_time;
   d[7].dp3=d+5;
   write_time_setting (d+5);
@@ -144,34 +151,34 @@ int rules_options (void)
   d[9].proc=0;
 
   while (retour==0)
-        {
-          choix=my_do_dialog (d,choix);
-          switch (choix)
-            {
-             case -1:
-             case MENU_QUICK_BACK:
-                  retour=1;
-                  break;
-             case MENU_QUICK_MAIN:
-                  retour=MENU_TOP;
-                  break;
-             case MENU_QUICK_QUIT:
-                  if (confirm_quit())
-                    retour=MENU_EXIT;
-                  break;
-             case MENU_QUICK_HELP:
-                  retour=display_help (HELP_TEXT_RULES);
-                  break;
-             case 8 :
-                  retour=advanced_options();
-                  break;
-             }
-        }
+    {
+      choix=my_do_dialog (d,choix);
+      switch (choix)
+	{
+	case -1:
+	case MENU_QUICK_BACK:
+	  retour=1;
+	  break;
+	case MENU_QUICK_MAIN:
+	  retour=MENU_TOP;
+	  break;
+	case MENU_QUICK_QUIT:
+	  if (confirm_quit())
+	    retour=MENU_EXIT;
+	  break;
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
+	  break;
+	case 8 :
+	  retour=advanced_options();
+	  break;
+	}
+    }
 
   if (retour>0)
     retour--;
 
- return retour;
+  return retour;
 }
 
 
