@@ -320,14 +320,19 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
   int result=0;
   int i,j;
   int start;
+  int started=0;
   LW_TEAMSTARTINFO team_start_info[NB_TEAMS];
   int cur_time,last_time;
   int display_waiting_for=1;
+  LW_CHAT_HISTORY chat;
+  LW_CHAT_MESSAGE chat_mess;
 
   reset(cont);
 
   cur_time=last_time=lw_srvtime_seconds();
 
+  lw_chat_reset(&chat);
+
   /*
    * We register the server on the metaserver for the
    * first time, with 0 active teams.
@@ -349,7 +354,8 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
        * Now we just wait until there are enough teams connected
        */
       while (cont->nb_teams<nb_teams && 
-	     cont->nb_chans<NB_TEAMS)
+	     cont->nb_chans<NB_TEAMS &&
+	     !started)
 	{
 	  free_teams=nb_teams-cont->nb_teams;
 
@@ -400,6 +406,21 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
 	      log_print_str("Starting game with only ");
 	      log_print_int(cont->nb_teams);
 	      log_println_str(" teams");
+
+	      started=1;
+	    }
+
+	  /*
+	   * We replicate chat messages
+	   */
+	  while (lw_chat_pop(&chat,&chat_mess))
+	    {
+	      for (i=0;i<cont->nb_chans;++i)
+		{
+		  lw_chat_push(&(cont->chan[i].chat),
+			       chat_mess.author,
+			       chat_mess.content);
+		}
 	    }
 
 	  /*
@@ -414,7 +435,8 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
 	    {
 	      if (!lw_srvchan_keepalive(&(cont->chan[i]),
 					free_teams,
-					team_start_info))
+					team_start_info,
+					&chat))
 		{
 		  /*
 		   * There's an error with this client, so 
