@@ -68,9 +68,9 @@
 
 static int TIME_TABLE[17]= {15,30,45,60,
                             90,120,150,180,
-                           240,300,360,480,
-                           600,900,1200,1800,
-                           3600};
+			    240,300,360,480,
+			    600,900,1200,1800,
+			    3600};
 static int TICKER_PAUSED;
 static int TICKER_START;
 static int TICKER_PAUSE_START;
@@ -88,58 +88,58 @@ int GLOBAL_CLOCK=0;
 /*------------------------------------------------------------------*/
 void update_play_time (void)
 {
- GLOBAL_TICKER=get_ticker()-TICKER_START;
- if (PAUSE_ON)
+  GLOBAL_TICKER=get_ticker()-TICKER_START;
+  if (PAUSE_ON)
     {
-     if (TICKER_PAUSE_START==0)
+      if (TICKER_PAUSE_START==0)
         TICKER_PAUSE_START=get_ticker();
     }
- else
-     {
+  else
+    {
       if (TICKER_PAUSE_START!=0)
-         {
+	{
           TICKER_PAUSED+=get_ticker()-TICKER_PAUSE_START;
           TICKER_PAUSE_START=0;
-         }
+	}
       else
-          TIME_ELAPSED=(get_ticker()-TICKER_START-TICKER_PAUSED)/1000;
-     }
- TIME_LEFT =TIME_TABLE[CONFIG_GAME_TIME]-TIME_ELAPSED;
+	TIME_ELAPSED=(get_ticker()-TICKER_START-TICKER_PAUSED)/1000;
+    }
+  TIME_LEFT =TIME_TABLE[LW_CONFIG_CURRENT_RULES.game_time]-TIME_ELAPSED;
 
- if (TIME_LEFT<0)
-       TIME_LEFT=0;
- if (TIME_LEFT<=5 && BELL_RINGING==0)
-      {
-       BELL_RINGING=1;
-       play_time ();
-      }
+  if (TIME_LEFT<0)
+    TIME_LEFT=0;
+  if (TIME_LEFT<=5 && BELL_RINGING==0)
+    {
+      BELL_RINGING=1;
+      play_time ();
+    }
 }
 
 /*------------------------------------------------------------------*/
 void start_play_time (void)
 {
- GLOBAL_CLOCK=2;
- TICKER_START=get_ticker();
- TICKER_PAUSED=0;
- TICKER_PAUSE_START=0;
- TIME_LEFT=TIME_TABLE[CONFIG_GAME_TIME]+1;
- BELL_RINGING=0;
- update_play_time();
+  GLOBAL_CLOCK=2;
+  TICKER_START=get_ticker();
+  TICKER_PAUSED=0;
+  TICKER_PAUSE_START=0;
+  TIME_LEFT=TIME_TABLE[LW_CONFIG_CURRENT_RULES.game_time]+1;
+  BELL_RINGING=0;
+  update_play_time();
 }
 
 /*------------------------------------------------------------------*/
 void write_time (int time, char *buffer)
 {
- int min,sec;
+  int min,sec;
 
- min=time/60;
- sec=time%60;
- buffer[0]='0'+min/10;
- buffer[1]='0'+min%10;
- buffer[2]=':';
- buffer[3]='0'+sec/10;
- buffer[4]='0'+sec%10;
- buffer[5]=0;
+  min=time/60;
+  sec=time%60;
+  buffer[0]='0'+min/10;
+  buffer[1]='0'+min%10;
+  buffer[2]=':';
+  buffer[3]='0'+sec/10;
+  buffer[4]='0'+sec%10;
+  buffer[5]=0;
 }
 
 
