@@ -98,12 +98,12 @@ int lw_wwwcli_get_games(LW_WWWCLI_DATA *buffer, int *size)
   int result=0;
   char buffer_content[LW_WWWCLI_HTTP_CONTENT_SIZE];
   char buffer_url[LW_WWWCLI_HTTP_URL_SIZE];
-  char *pos;
+  char *pos,*pos_tmp;
   int i=0;
 
   log_print_str("Getting server list from \"");
   log_print_str(STARTUP_METASERVER);
-  log_print_str("\"");
+  log_print_str("\" ");
 
   memset(&buffer_url,0,sizeof(buffer_url));
   strcpy(buffer_url,STARTUP_METASERVER);
@@ -118,18 +118,44 @@ int lw_wwwcli_get_games(LW_WWWCLI_DATA *buffer, int *size)
 
       while (read_eol(&pos));
 
-      while (i<(*size) && parse_line(buffer+i,&pos))
+      while (i<(*size) && strlen(pos)>0)
 	{
-	  if (buffer[i].busy_players < buffer[i].max_players)
+	  pos_tmp=pos;
+	  if (read_eol(&pos_tmp))
 	    {
 	      /*
-	       * we increment i only if there's some room left on the
-	       * server. If it's full of people playing on it, it's
-	       * of absolutely no use to present it as a working
-	       * server... And not incrementing i will make it be
-	       * overwritten by the next server.
+	       * This was just an empty line...
 	       */
-	      ++i;
+	      pos=pos_tmp;
+	    }
+	  else
+	    {
+	      /*
+	       * We parse the line only if there's something on it...
+	       */
+	      if (parse_line(buffer+i,&pos))
+		{
+		  if (buffer[i].busy_players < buffer[i].max_players)
+		    {
+		      /*
+		       * we increment i only if there's some room left on the
+		       * server. If it's full of people playing on it, it's
+		       * of absolutely no use to present it as a working
+		       * server... And not incrementing i will make it be
+		       * overwritten by the next server.
+		       */
+		      ++i;
+		      log_print_str("+");
+		    }
+		  else
+		    {
+		      log_print_str("=");
+		    }
+		}
+	      else
+		{
+		  log_print_str("-");
+		}
 	    }
 	}
 
@@ -189,10 +215,11 @@ int parse_line(LW_WWWCLI_DATA *result, char **str)
 	      result->ip,
 	      result->busy_players,
 	      result->max_players);
-      next_line(str);
       ok=1;
     }
 
+  next_line(str);
+
   return ok;
 }
 
@@ -202,7 +229,7 @@ int parse_line(LW_WWWCLI_DATA *result, char **str)
  */
 void skip_space(char **str)
 {
-  while (isspace(**str) && (**str)!='\n')
+  while ((isspace(**str) || (**str)=='\r') && (**str)!='\n')
     {
       ++(*str);
     }
@@ -225,7 +252,7 @@ int read_string(char *result,char **str,int size)
   if (c=='\'')
     {
       ++(*str);
-      while ((c=**str)!='\0' && c!='\n' && i<size-1 && !done)
+      while ((c=**str)!='\0' && c!='\n' && !done)
 	{
 	  ++(*str);
 	  if (c=='\'')
@@ -233,7 +260,10 @@ int read_string(char *result,char **str,int size)
 	      if ((**str)=='\'')
 		{
 		  ++(*str);
-		  result[i++]='\'';
+		  if (i<size-1)
+		    {
+		      result[i++]='\'';
+		    }
 		}
 	      else
 		{
@@ -242,7 +272,10 @@ int read_string(char *result,char **str,int size)
 	    }
 	  else
 	    {
-	      result[i++]=c;
+	      if (i<size-1)
+		{
+		  result[i++]=c;
+		}
 	    }
 	}
     }
